@@ -1,8 +1,10 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* Bison interface for Yacc-like parsers in C
+/* A Bison parser, made by GNU Bison 2.4.1.  */
+
+/* Skeleton interface for Bison's Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -1246,8 +1248,8 @@
 typedef union YYSTYPE
 {
 
-/* Line 2068 of yacc.c  */
-#line 731 "/mnt/workspace/percona-xtradb-cluster-5.5-source-tarball-bzr/sql/sql_yacc.yy"
+/* Line 1676 of yacc.c  */
+#line 731 "/var/lib/jenkins/jobs/percona-xtradb-cluster-5.5-source-tarball-bzr/workspace/sql/sql_yacc.yy"
 
   int  num;
   ulong ulong_num;
@@ -1298,8 +1300,8 @@ typedef union YYSTYPE
 
 
 
-/* Line 2068 of yacc.c  */
-#line 1303 "/mnt/workspace/percona-xtradb-cluster-5.5-source-tarball-bzr/sql/sql_yacc.h"
+/* Line 1676 of yacc.c  */
+#line 1305 "/var/lib/jenkins/jobs/percona-xtradb-cluster-5.5-source-tarball-bzr/workspace/sql/sql_yacc.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
