@@ -194,7 +194,7 @@ extern wsrep_seqno_t wsrep_locked_seqno;
   (global_system_variables.wsrep_on)
 
 #define WSREP(thd) \
-  (WSREP_ON && (thd && thd->variables.wsrep_on))
+  (WSREP_ON && wsrep && (thd && thd->variables.wsrep_on))
 
 #define WSREP_CLIENT(thd) \
     (WSREP(thd) && thd->wsrep_client_thread)
